@@ -3,7 +3,7 @@ hmKeywords:"Profiles,Profiles WebDAV,WebDAV",
 hmTitle:"WebDAV Profile Settings",
 hmDescription:"URL, Username, Password, Recursive listings Specify parameters for your account. The Description can include any text you want.",
 hmPrevLink:"profilesvn.html",
-hmNextLink:"dlgsourcecontrolmanager.html",
+hmNextLink:"admin_policies.html",
 hmParentLink:"dlgprofilemanager.html",
 hmBreadCrumbs:"<a href=\"settings_reference.html\">Settings Reference<\/a> &gt; <a href=\"dlgprofilemanager.html\">Profiles<\/a>",
 hmTitlePath:"Settings Reference > Profiles > WebDAV Profiles",
