@@ -1,82 +1,84 @@
-pageinfo = [[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
+pageinfo = [[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
 	[1715027042,0,0,0,null],
 	[1398282942,0,0,0,null],
 	[1715027042,0,0,0,null],
@@ -92,142 +94,143 @@ pageinfo = [[1753292994,0,0,0,null],
 	[1398282942,0,0,0,null],
 	[1398282942,0,0,0,null],
 	[1716915102,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null],
-	[1753292994,0,0,0,null]];
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null],
+	[1769604640,0,0,0,null]];
 pagedata = [ ["./3-way_merge_concepts.html","3-way Merge Concepts","A merge session helps you combine separate sets of changes into a new version of the data, accommodating both sets of changes.","./images/zoomimage.jpg"],
+["./admin_policies.html","Admin Policies","Beyond Compare allows system administrators to disable certain functionality of the program by setting policies in a system-wide location.","./images/zoomimage.jpg"],
 ["./archive_files.html","Archive Files","Archives are files that contain other files, such as .zip.  Beyond Compare displays them as folders, with a zipper icon, but by default treat...","./images/zoomimage.jpg"],
 ["./bcclipmain.html","Clipboard Compare Overview","Clipboard Compare runs in the background, keeping track of every time the Windows clipboard is updated with text.  It appears in the Windows ...","./images/zoomimage.jpg"],
 ["./bcclipoptions.html","Clipboard Compare Options","These options control the behavior of Clipboard Compare.","./images/zoomimage.jpg"],
@@ -251,6 +254,7 @@ pagedata = [ ["./3-way_merge_concepts.html","3-way Merge Concepts","A merge sess
 ["./commandsver.html","Version Compare Commands","Following is a description of the Version Compare commands, in addition to the common commands.  Most of these commands are available as tool...","./images/zoomimage.jpg"],
 ["./commands_reference.html","Commands Reference","This part of the documentation describes the commands available in menus and on the toolbar for each view type.","./images/zoomimage.jpg"],
 ["./command_line_reference.html","Command Line Reference","Command line executable files Executable Meaning BCompare.exe  bcompare   This is the main application.  Only one copy will run at ...","./images/zoomimage.jpg"],
+["./dir_columns.html","Folder Columns","Name The name of the file or folder.  If the Ext column is hidden then the read-only (r), system (s), and hidden (h) attributes will be shown...","./images/zoomimage.jpg"],
 ["./dir_filtering_the_view.html","Filtering the Folder Compare View","There are three overall type of filters you can use to control a Folder Compare session&#39;s scope:  File Filters that include or exclude files ...","./images/zoomimage.jpg"],
 ["./dir_how_to_compare.html","How to Compare in the Folder Compare","There are several ways to compare folders and files.","./images/zoomimage.jpg"],
 ["./dir_merge_understanding_the_display.html","Understanding the Folder Merge Display","The Folder Merge display uses color cues to highlight the differences between the base folders.  By default, the color meanings are:","./images/zoomimage.jpg"],
@@ -261,8 +265,8 @@ pagedata = [ ["./3-way_merge_concepts.html","3-way Merge Concepts","A merge sess
 ["./display_filters.html","Display Filters","Display filters limit the view to certain comparison results.  For example, you can pick Show Differences  to hide all the matching file...","./images/zoomimage.jpg"],
 ["./dlgbrowsemachine.html","Selecting a Remote Registry","If the remote computer you want to connect with does not appear in the list, you may need to do the following:","./images/zoomimage.jpg"],
 ["./dlgdiralignwithitem.html","Editing an Alignment Override","Fill in the Align left file (or folder) and with right file (or folder) edits.","./images/zoomimage.jpg"],
-["./dlgdirfind.html","Finding Filenames","To locate a specific file in a folder view, pick Search &#62; Find Filename .","./images/zoomimage.jpg"],
-["./dlgdirotherfilteritem.html","Editing an Other Filter Item","To filter by date Pick Older than or Newer than. If the Day(s) ago checkbox is marked, this filter will be the number of whole days relative to 12...","./images/zoomimage.jpg"],
+["./dlgdirfind.html","Finding Filenames","To locate a specific file or folder in a folder view, pick Search &#62; Find Filename .","./images/zoomimage.jpg"],
+["./dlgdirotherfilteritem.html","Editing an Other Filter Item","To filter on date modified Pick Older than or Newer than. If the Day(s) ago checkbox is marked, this filter will be the number of whole days relat...","./images/zoomimage.jpg"],
 ["./dlgexport.html","Exporting Settings","You can selectively save your program settings, in order to transfer them to another computer, upgrade to a newer version, or share them with anot...","./images/zoomimage.jpg"],
 ["./dlgfileformatmanager.html","File Format Management","Pick Tools &#62; File Formats  to see and manage the entire list of file formats.","./images/zoomimage.jpg"],
 ["./dlgimport.html","Importing Settings","You can import settings that were previously exported from Beyond Compare, even an older version like Beyond Compare 3.","./images/zoomimage.jpg"],
@@ -278,7 +282,7 @@ pagedata = [ ["./3-way_merge_concepts.html","3-way Merge Concepts","A merge sess
 ["./dlgsourcecontrolmanager.html","Source Control Integration","Pick Tools &#62; Source Control Integration to associate folders with your SCC-compatible source control application so that Beyond Compare can off...","./images/zoomimage.jpg"],
 ["./dlgsupport.html","Reporting Problems","If you have found a problem with Beyond Compare, we would like to hear from you!","./images/zoomimage.jpg"],
 ["./dlgtablecolhandling.html","Editing Column Handling","The Column Handling dialog allows you to set options for each comparison column.  A subset of this dialog is used to set default handling for...","./images/zoomimage.jpg"],
-["./dlgtextfindinfiles.html","Finding Text in Files","To locate specific text in multiple files, pick Search &#62; Find in Files .","./images/zoomimage.jpg"],
+["./dlgtextfindinfiles.html","Finding Text in Files","In a Text Edit view, pick Search &#62; Find in Files  to locate specific text in multiple files.","./images/zoomimage.jpg"],
 ["./dlgtextgrammaritem.html","Editing a Grammar Item","Pick an existing Element name from the dropdown list or enter your own new name.","./images/zoomimage.jpg"],
 ["./dlgtextreplacementitem.html","Editing a Text Replacement Item","Specify the Text to find and the Replace with text.","./images/zoomimage.jpg"],
 ["./dlgworkspacemanager.html","Managing Workspaces","To save your current workspace configuration Pick Session &#62; Save Workspace As. Enter a unique name or pick a saved workspace to be replaced fro...","./images/zoomimage.jpg"],
@@ -436,7 +440,7 @@ pagedata = [ ["./3-way_merge_concepts.html","3-way Merge Concepts","A merge sess
 ["./snapshots.html","Snapshots","In the Tools menu, the Save Snapshot  command saves a compressed read-only listing of the specified folder and all of its subfolders, includi...","./images/zoomimage.jpg"],
 ["./specs.html","Specs","A Spec is the name of a folder or file.  Beyond Compare supports several different types of specs.","./images/zoomimage.jpg"],
 ["./standard_vs_pro.html","Standard vs Pro Editions","The Standard edition of Beyond Compare is a powerful full-featured comparison tool, not a stripped-down \"lite\" version.  The Standa...","./images/zoomimage.jpg"],
-["./support_ordering_and_license.html","Support, Ordering, and License","For the latest version of Beyond Compare and for other news about the program, visit our web site at:  www.scootersoftware.com","./images/zoomimage.jpg"],
+["./support_ordering_and_license.html","Support, Ordering, and License","For the latest version of Beyond Compare and for other news about the program, visit our web site at:","./images/zoomimage.jpg"],
 ["./table_working_with_multiple.html","Working with Multiple Sheets","When you are comparing files that contain multiple sheets, click the tabs at the bottom of the Table Compare view to switch between comparison she...","./images/zoomimage.jpg"],
 ["./using_bc.html","Using Beyond Compare","Beyond Compare handles a wide variety of comparison tasks.  It has specialized views for different kinds of files and different approaches to...","./images/zoomimage.jpg"],
 ["./using_text_merge.html","Using Text Merge","Once Beyond Compare has completed the comparison it will show up to four panes:  The left, center, and right panes at the top, with an output...","./images/zoomimage.jpg"],
